@@ -197,44 +197,51 @@ bool SmsSender::send(QString number, QString messageText)
     //Implementation using pnatd (must be run as root)
     //to run it as user:
     // chmod 4555 /usr/bin/pnatd
+    bool res = true;
     Pty* pty = new Pty();
     QStringList args;
     if (!pty->run("pnatd", args)){
         consoleOutput(QString("ERR: Failed to run pnatd"));
-        return false;
+        res = false;
     }
 
-    if (!writeCmd(pty, "AT\r", "OK")){
-        //consoleOutput(QString("ERR: Failed to send at command"));
-        //return false;
+    if (res){
+        writeCmd(pty, "AT\r", "OK");
+        consoleOutput(".", false);
     }
-    consoleOutput(".", false);
 
     //AT+CPIN="0000" <-- TODO: send if the SIM is pin-protected
-    if (!writeCmd(pty, "AT+CMGF=1\r", "OK")){
-        consoleOutput(QString("ERR: Failed to send at+cmgf command"));
-        //return false;
+    if (res){
+        if (!writeCmd(pty, "AT+CMGF=1\r", "OK")){
+            consoleOutput(QString("\nERR: Failed to send at+cmgf command"));
+            res = false;
+        }else
+            consoleOutput(".", false);
     }
-    consoleOutput(".", false);
 
-    if (!writeCmd(pty, QString("AT+CMGS=\"%1\"\r").arg(number).toLatin1(), ">")){
-        consoleOutput(QString("ERR: Failed to send at+cmgs command"));
-        //return false;
+    if (res){
+        if (!writeCmd(pty, QString("AT+CMGS=\"%1\"\r").arg(number).toLatin1(), ">")){
+            consoleOutput(QString("\nERR: Failed to send at+cmgs command"));
+            res = false;
+        }else
+            consoleOutput(".", false);
     }
-    consoleOutput(".", false);
 
-    if (!writeCmd(pty, messageText, "")){
-        consoleOutput(QString("ERR: Failed to send text message"));
-        //return false;
+    if (res){
+        if (!writeCmd(pty, messageText, "")){
+            consoleOutput(QString("\nERR: Failed to send text message"));
+            res = false;
+        }else
+            consoleOutput(".", false);
     }
-    consoleOutput(".", false);
-
-    bool res = writeCmd(pty, QString("%1").arg(QChar(26)).toLatin1(), "OK", -1);
-    if (!res)
-        consoleOutput("FAILED");
-    else
-        consoleOutput("OK");
 
+    if (res){
+        res = writeCmd(pty, QString("%1").arg(QChar(26)).toLatin1(), "OK", -1);
+        if (!res)
+            consoleOutput("FAILED");
+        else
+            consoleOutput("OK");
+    }
     delete pty;
     return res;
 }
